==> nextcloud-13.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/settings/l10n/uk.js <==
OC.L10N.register(
    "settings",
    {
    "{actor} changed your password" : "{actor} змінив ваш пароль",
    "{actor} changed your email address" : "{actor} змінив вашу email адресу",
    "You changed your email address" : "Ви змінили вашу email адресу",
    "Your email address was changed by an administrator" : "Ваша email адреса змінена адміністратором",
    "Wrong password" : "Невірний пароль",
    "Saved" : "Збережено",
    "No user supplied" : "Користувача не вказано",
    "Unable to change password" : "Неможливо змінити пароль",
    "Authentication error" : "Помилка автентифікації",
    "Wrong admin recovery password. Please check the password and try again." : "Невірний пароль відновлення адміністратора.  Будь ласка, перевірте пароль та спробуйте ще раз.",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "встановлення та оновлення додатків через магазин додатків або Об’єднання хмарних сховищ",
    "Federated Cloud Sharing" : "Об’єднання хмарних сховищ",
    "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "cURL використовує застарілу версію %s (%s). Будь ласка, поновіть вашу операційну систему або функції, такі як %s не працюватимуть надійно.",
    "Group already exists." : "Група вже існує.",
    "Unable to add group." : "Неможливо додати групу.",
    "Unable to delete group." : "Неможливо видалити групу.",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Під час надсилання email сталася помилка. Будь ласка перевірте налаштування. (Помилка: %s)",
    "You need to set your user email before being able to send test emails." : "Перед надсиланням тестових листів ви повинні вказати свою email адресу.",
    "Invalid mail address" : "Неправильна email адреса",
    "A user with that name already exists." : "Користувач з таким іменем вже існує.",
    "Unable to create user." : "Неможливо створити користувача.",
    "Unable to delete user." : "Неможливо видалити користувача.",
    "Unable to change full name" : "Неможливо змінити повне ім'я",
    "Your full name has been changed." : "Ваше повне ім'я було змінено",
    "Forbidden" : "Заборонено",
    "Invalid user" : "Неправильний користувач",
    "Unable to change mail address" : "Неможливо поміняти email адресу",
    "Email saved" : "Адресу збережено",
    "Your %s account was created" : "Ваш %s аккаунт створений",
    "Couldn't remove app." : "Неможливо видалити додаток.",
    "Couldn't update app." : "Не вдалося оновити додаток. ",
    "Migration in progress. Please wait until the migration is finished" : "Міграція триває. Будь ласка, зачекайте доки процес міграції завершиться",
    "Migration started …" : "Міграцію розпочато ...",
    "Email sent" : "Лист надіслано",
    "Official" : "Офіційні",
    "All" : "Всі",
    "Update to %s" : "Оновити до %s",
    "No apps found for your version" : "Немає застосунків для вашої версії",
    "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Схвалені додатки розроблені довіреними розробниками і пройшли незалежну перевірку безпеки. Їх активно супроводжують у репозиторії з відкритим кодом, а їх розробники стежать, щоб вони були стабільні й прийнятні для повсякденного використання.",
    "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Ця програма не перевірена на вразливості безпеки і є новою або нестабільною. Встановлюйте її на власний ризик.",
    "Error while disabling app" : "Помилка вимикання додатка",
    "Disable" : "Вимкнути",
    "Enable" : "Увімкнути",
    "Error while enabling app" : "Помилка вмикання додатка",
    "Updated" : "Оновлено",
    "Approved" : "Схвалені",
    "Experimental" : "Експериментальні",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Виникла помилка. Будь ласка вивантажте PEM сертифікат в ASCII-кодуванні.",
    "Valid until {date}" : "Дійсно до {date}",
    "Delete" : "Видалити",
    "Select a profile picture" : "Обрати зображення облікового запису",
    "Very weak password" : "Дуже слабкий пароль",
    "Weak password" : "Слабкий пароль",
    "So-so password" : "Такий собі пароль",
    "Good password" : "Добрий пароль",
    "Strong password" : "Надійний пароль",
    "Groups" : "Групи",
    "Unable to delete {objName}" : "Не вдалося видалити {objName}",
    "A valid group name must be provided" : "Потрібно задати вірне ім'я групи",
    "deleted {groupName}" : "видалено {groupName}",
    "undo" : "відмінити",
    "never" : "ніколи",
    "deleted {userName}" : "видалено {userName}",
    "Changing the password will result in data loss, because data recovery is not available for this user" : "Зміна пароля призведе до втрати даних, тому що відновлення даних не доступно для цього користувача",
    "A valid username must be provided" : "Потрібно задати вірне ім'я користувача",
    "Developer documentation" : "Документація для розробників",
    "Documentation:" : "Документація:",
    "User documentation" : "Користувацька документація",
    "Admin documentation" : "Документація адміністратора",
    "Show description …" : "Показати деталі ...",
    "Hide description …" : "Сховати деталі ...",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Ця програма не може бути встановлено, так як наступні залежності не будуть виконані:",
    "Enable only for specific groups" : "Включити тільки для конкретних груп",
    "Common Name" : "Ім'я:",
    "Valid until" : "Дійсно до",
    "Issued By" : "Виданий",
    "Valid until %s" : "Дійсно до %s",
    "Import root certificate" : "Імпортувати кореневий сертифікат",
    "Administrator documentation" : "Документація адміністратора",
    "Online documentation" : "Документація онлайн",
    "Forum" : "Форум",
    "Commercial support" : "Комерційна підтримка",
    "None" : "Жоден",
    "Login" : "Логін",
    "Plain" : "Звичайний",
    "NT LAN Manager" : "Менеджер NT LAN",
    "Email server" : "Сервер електронної пошти",
    "Open documentation" : "Відкрити документацію",
    "Send mode" : "Режим надсилання",
    "Encryption" : "Шифрування",
    "From address" : "Адреса відправника",
    "mail" : "пошта",
    "Authentication method" : "Спосіб аутентифікації",
    "Authentication required" : "Потрібна аутентифікація",
    "Server address" : "Адреса сервера",
    "Port" : "Порт",
    "Credentials" : "Облікові дані",
    "SMTP Username" : "Ім'я користувача SMTP",
    "SMTP Password" : "Пароль SMTP",
    "Store credentials" : "Зберігати облікові дані",
    "Test email settings" : "Тестувати налаштування електронної пошти",
    "Send email" : "Надіслати листа",
    "Server-side encryption" : "Шифрування на сервері",
    "Enable server-side encryption" : "Увімкнути шифрування на сервері",
    "Please read carefully before activating server-side encryption: " : "Будьте обережні під час активування шифрування на сервері:",
    "Enable encryption" : "Увімкнути шифрування",
    "Select default encryption module:" : "Обрати модуль шифрування за замовчуванням:",
    "Start migration" : "Розпочати міграцію",
    "Security & setup warnings" : "Попередження безпеки та налаштування",
    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Тільки перегляд був включений. Це запобігає встановити деякі конфігурації через веб-інтерфейс. Крім того, файл повинен бути доступний для запису вручну для кожного оновлення.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Це, ймовірно, обумовлено використанням кеша/прискорювача такого як Zend OPcache або eAccelerator.",
    "System locale can not be set to a one which supports UTF-8." : "Неможливо встановити системну локаль, яка б підтримувала UTF-8.",
    "All checks passed." : "Всі перевірки пройдено.",
    "Execute one task with each page loaded" : "Виконати одне завдання для кожної завантаженої сторінки ",
    "Version" : "Версія",
    "Sharing" : "Спільний доступ",
    "Allow apps to use the Share API" : "Дозволити програмам використовувати API спільного доступу",
    "Allow users to share via link" : "Дозволити користувачам ділитися через посилання",
    "Allow public uploads" : "Дозволити публічне завантаження",
    "Enforce password protection" : "Захист паролем обов'язковий",
    "Set default expiration date" : "Встановити термін дії за замовчуванням",
    "Expire after " : "Скінчиться через",
    "days" : "днів",
    "Enforce expiration date" : "Термін дії обов'язковий",
    "Allow resharing" : "Дозволити перевідкривати спільний доступ",
    "Restrict users to only share with users in their groups" : "Дозволити користувачам відкривати спільний доступ лише для користувачів з їхньої групи",
    "Exclude groups from sharing" : "Виключити групи зі спільного доступу",
    "These groups will still be able to receive shares, but not to initiate them." : "Ці групи зможуть отримувати спільні файли, але не зможуть відправляти їх.",
    "Tips & tricks" : "Поради і трюки",
    "How to do backups" : "Як робити резервне копіювання",
    "Performance tuning" : "Налаштування продуктивності",
    "Improving the config.php" : "Покращення  config.php",
    "Theming" : "Оформлення",
    "Hardening and security guidance" : "Інструктування з безпеки та захисту",
    "You are using <strong>%s</strong> of <strong>%s</strong>" : "Ви використовуєте <strong>%s</strong> з <strong>%s</strong>",
    "Profile picture" : "Зображення облікового запису",
    "Upload new" : "Завантажити нове",
    "Remove image" : "Видалити зображення",
    "Cancel" : "Відмінити",
    "Choose as profile picture" : "Обрати як зображення для профілю",
    "You are member of the following groups:" : "Ви є членом наступних груп:",
    "Full name" : "Повне ім'я",
    "No display name set" : "Коротке ім'я не вказано",
    "Email" : "E-mail",
    "Your email address" : "Ваша адреса електронної пошти",
    "No email address set" : "E-mail не вказано",
    "Phone number" : "Номер телефону",
    "Your phone number" : "Ваш номер телефону",
    "Address" : "Адреса",
    "Language" : "Мова",
    "Help translate" : "Допомогти з перекладом",
    "Password" : "Пароль",
    "Current password" : "Поточний пароль",
    "New password" : "Новий пароль",
    "Change password" : "Змінити пароль",
    "Username" : "Ім'я користувача",
    "Done" : "Готово",
    "Show storage location" : "Показати місцезнаходження сховища",
    "Show user backend" : "Показати користувача",
    "Everyone" : "Всі",
    "Admins" : "Адміністратори",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Будь ласка, вкажіть розмір сховища (наприклад: \"512 MB\" або \"12 GB\")",
    "Unlimited" : "Необмежено",
    "Other" : "Інше",
    "Quota" : "Квота",
    "E-Mail" : "Адреса електронної пошти",
    "Admin Recovery Password" : "Пароль адміністратора для відновлення",
    "Enter the recovery password in order to recover the users files during password change" : "Введіть пароль для того, щоб відновити файли користувачів при зміні паролю",
    "change full name" : "змінити ім'я",
    "set new password" : "встановити новий пароль",
    "change email address" : "Змінити адресу електронної пошти",
    "Default" : "За замовчуванням",
    "A problem occurred, please check your log files (Error: %s)" : "Виникла проблема, будь ласка, перевірте свої файли журналів (Помилка: %s)",
    "Migration Completed" : "Міграцію завершено",
    "Add trusted domain" : "Додати довірений домен",
    "A valid password must be provided" : "Потрібно задати вірний пароль",
    "A valid email must be provided" : "Вкажіть дійсний email",
    "Show email address" : "Показати адресу електронної пошти",
    "Send email to new user" : "Надіслати email новому користувачу",
    "Create" : "Створити"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-13.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/settings/l10n/uk.js <==
OC.L10N.register(
    "settings",
    {
    "{actor} changed your password" : "{actor} змінив ваш пароль",
    "{actor} changed your email address" : "{actor} змінив вашу email адресу",
    "You changed your email address" : "Ви змінили вашу email адресу",
    "Your email address was changed by an administrator" : "Ваша email адреса змінена адміністратором",
    "Couldn't remove app." : "Неможливо видалити додаток.",
    "Couldn't update app." : "Не вдалося оновити додаток. ",
    "Wrong password" : "Невірний пароль",
    "Saved" : "Збережено",
    "No user supplied" : "Користувача не вказано",
    "Unable to change password" : "Неможливо змінити пароль",
    "Authentication error" : "Помилка автентифікації",
    "Wrong admin recovery password. Please check the password and try again." : "Невірний пароль відновлення адміністратора.  Будь ласка, перевірте пароль та спробуйте ще раз.",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "встановлення та оновлення додатків через магазин додатків або Об’єднання хмарних сховищ",
    "Federated Cloud Sharing" : "Об’єднання хмарних сховищ",
    "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "cURL використовує застарілу версію %s (%s). Будь ласка, поновіть вашу операційну систему або функції, такі як %s не працюватимуть надійно.",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Під час надсилання email сталася помилка. Будь ласка перевірте налаштування. (Помилка: %s)",
    "You need to set your user email before being able to send test emails." : "Перед надсиланням тестових листів ви повинні вказати свою email адресу.",
    "Invalid mail address" : "Неправильна email адреса",
    "Unable to change full name" : "Неможливо змінити повне ім'я",
    "Your %s account was created" : "Ваш %s аккаунт створений",
    "Migration in progress. Please wait until the migration is finished" : "Міграція триває. Будь ласка, зачекайте доки процес міграції завершиться",
    "Migration started …" : "Міграцію розпочато ...",
    "Email sent" : "Лист надіслано",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Виникла помилка. Будь ласка вивантажте PEM сертифікат в ASCII-кодуванні.",
    "Valid until {date}" : "Дійсно до {date}",
    "Delete" : "Видалити",
    "Select a profile picture" : "Обрати зображення облікового запису",
    "Very weak password" : "Дуже слабкий пароль",
    "Weak password" : "Слабкий пароль",
    "So-so password" : "Такий собі пароль",
    "Good password" : "Добрий пароль",
    "Strong password" : "Надійний пароль",
    "Groups" : "Групи",
    "Official" : "Офіційні",
    "User documentation" : "Користувацька документація",
    "Developer documentation" : "Документація для розробників",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Ця програма не може бути встановлено, так як наступні залежності не будуть виконані:",
    "Enable" : "Увімкнути",
    "Full name" : "Повне ім'я",
    "Email" : "E-mail",
    "Unlimited" : "Необмежено",
    "Error while enabling app" : "Помилка вмикання додатка",
    "Admins" : "Адміністратори",
    "Everyone" : "Всі",
    "Common Name" : "Ім'я:",
    "Valid until" : "Дійсно до",
    "Issued By" : "Виданий",
    "Valid until %s" : "Дійсно до %s",
    "Import root certificate" : "Імпортувати кореневий сертифікат",
    "Administrator documentation" : "Документація адміністратора",
    "Online documentation" : "Документація онлайн",
    "Forum" : "Форум",
    "Commercial support" : "Комерційна підтримка",
    "None" : "Жоден",
    "Login" : "Логін",
    "Plain" : "Звичайний",
    "NT LAN Manager" : "Менеджер NT LAN",
    "Email server" : "Сервер електронної пошти",
    "Open documentation" : "Відкрити документацію",
    "Send mode" : "Режим надсилання",
    "Encryption" : "Шифрування",
    "From address" : "Адреса відправника",
    "mail" : "пошта",
    "Authentication method" : "Спосіб аутентифікації",
    "Authentication required" : "Потрібна аутентифікація",
    "Server address" : "Адреса сервера",
    "Port" : "Порт",
    "Credentials" : "Облікові дані",
    "SMTP Username" : "Ім'я користувача SMTP",
    "SMTP Password" : "Пароль SMTP",
    "Store credentials" : "Зберігати облікові дані",
    "Test email settings" : "Тестувати налаштування електронної пошти",
    "Send email" : "Надіслати листа",
    "Server-side encryption" : "Шифрування на сервері",
    "Enable server-side encryption" : "Увімкнути шифрування на сервері",
    "Please read carefully before activating server-side encryption: " : "Будьте обережні під час активування шифрування на сервері:",
    "Enable encryption" : "Увімкнути шифрування",
    "Select default encryption module:" : "Обрати модуль шифрування за замовчуванням:",
    "Start migration" : "Розпочати міграцію",
    "Security & setup warnings" : "Попередження безпеки та налаштування",
    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Тільки перегляд був включений. Це запобігає встановити деякі конфігурації через веб-інтерфейс. Крім того, файл повинен бути доступний для запису вручну для кожного оновлення.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Це, ймовірно, обумовлено використанням кеша/прискорювача такого як Zend OPcache або eAccelerator.",
    "System locale can not be set to a one which supports UTF-8." : "Неможливо встановити системну локаль, яка б підтримувала UTF-8.",
    "All checks passed." : "Всі перевірки пройдено.",
    "Version" : "Версія",
    "Execute one task with each page loaded" : "Виконати одне завдання для кожної завантаженої сторінки ",
    "Sharing" : "Спільний доступ",
    "Allow apps to use the Share API" : "Дозволити програмам використовувати API спільного доступу",
    "Allow users to share via link" : "Дозволити користувачам ділитися через посилання",
    "Allow public uploads" : "Дозволити публічне завантаження",
    "Enforce password protection" : "Захист паролем обов'язковий",
    "Set default expiration date" : "Встановити термін дії за замовчуванням",
    "Expire after " : "Скінчиться через",
    "days" : "днів",
    "Enforce expiration date" : "Термін дії обов'язковий",
    "Allow resharing" : "Дозволити перевідкривати спільний доступ",
    "Restrict users to only share with users in their groups" : "Дозволити користувачам відкривати спільний доступ лише для користувачів з їхньої групи",
    "Exclude groups from sharing" : "Виключити групи зі спільного доступу",
    "These groups will still be able to receive shares, but not to initiate them." : "Ці групи зможуть отримувати спільні файли, але не зможуть відправляти їх.",
    "Tips & tricks" : "Поради і трюки",
    "How to do backups" : "Як робити резервне копіювання",
    "Performance tuning" : "Налаштування продуктивності",
    "Improving the config.php" : "Покращення  config.php",
    "Theming" : "Оформлення",
    "Hardening and security guidance" : "Інструктування з безпеки та захисту",
    "Profile picture" : "Зображення облікового запису",
    "Upload new" : "Завантажити нове",
    "Remove image" : "Видалити зображення",
    "Cancel" : "Відмінити",
    "Choose as profile picture" : "Обрати як зображення для профілю",
    "You are member of the following groups:" : "Ви є членом наступних груп:",
    "No display name set" : "Коротке ім'я не вказано",
    "Your email address" : "Ваша адреса електронної пошти",
    "No email address set" : "E-mail не вказано",
    "Phone number" : "Номер телефону",
    "Your phone number" : "Ваш номер телефону",
    "Address" : "Адреса",
    "Language" : "Мова",
    "Help translate" : "Допомогти з перекладом",
    "Password" : "Пароль",
    "Current password" : "Поточний пароль",
    "New password" : "Новий пароль",
    "Change password" : "Змінити пароль",
    "Username" : "Ім'я користувача",
    "Done" : "Готово",
    "A problem occurred, please check your log files (Error: %s)" : "Виникла проблема, будь ласка, перевірте свої файли журналів (Помилка: %s)",
    "Migration Completed" : "Міграцію завершено",
    "Group already exists." : "Група вже існує.",
    "Unable to add group." : "Неможливо додати групу.",
    "Unable to delete group." : "Неможливо видалити групу.",
    "A user with that name already exists." : "Користувач з таким іменем вже існує.",
    "Unable to create user." : "Неможливо створити користувача.",
    "Unable to delete user." : "Неможливо видалити користувача.",
    "Your full name has been changed." : "Ваше повне ім'я було змінено",
    "Forbidden" : "Заборонено",
    "Invalid user" : "Неправильний користувач",
    "Unable to change mail address" : "Неможливо поміняти email адресу",
    "Email saved" : "Адресу збережено",
    "Add trusted domain" : "Додати довірений домен",
    "All" : "Всі",
    "Update to %s" : "Оновити до %s",
    "No apps found for your version" : "Немає застосунків для вашої версії",
    "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Схвалені додатки розроблені довіреними розробниками і пройшли незалежну перевірку безпеки. Їх активно супроводжують у репозиторії з відкритим кодом, а їх розробники стежать, щоб вони були стабільні й прийнятні для повсякденного використання.",
    "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Ця програма не перевірена на вразливості безпеки і є новою або нестабільною. Встановлюйте її на власний ризик.",
    "Error while disabling app" : "Помилка вимикання додатка",
    "Disable" : "Вимкнути",
    "Updated" : "Оновлено",
    "Approved" : "Схвалені",
    "Experimental" : "Експериментальні",
    "Unable to delete {objName}" : "Не вдалося видалити {objName}",
    "A valid group name must be provided" : "Потрібно задати вірне ім'я групи",
    "deleted {groupName}" : "видалено {groupName}",
    "undo" : "відмінити",
    "never" : "ніколи",
    "deleted {userName}" : "видалено {userName}",
    "Changing the password will result in data loss, because data recovery is not available for this user" : "Зміна пароля призведе до втрати даних, тому що відновлення даних не доступно для цього користувача",
    "A valid username must be provided" : "Потрібно задати вірне ім'я користувача",
    "A valid password must be provided" : "Потрібно задати вірний пароль",
    "A valid email must be provided" : "Вкажіть дійсний email",
    "Documentation:" : "Документація:",
    "Admin documentation" : "Документація адміністратора",
    "Show description …" : "Показати деталі ...",
    "Hide description …" : "Сховати деталі ...",
    "Enable only for specific groups" : "Включити тільки для конкретних груп",
    "You are using <strong>%s</strong> of <strong>%s</strong>" : "Ви використовуєте <strong>%s</strong> з <strong>%s</strong>",
    "Show storage location" : "Показати місцезнаходження сховища",
    "Show user backend" : "Показати користувача",
    "Show email address" : "Показати адресу електронної пошти",
    "Send email to new user" : "Надіслати email новому користувачу",
    "E-Mail" : "Адреса електронної пошти",
    "Create" : "Створити",
    "Admin Recovery Password" : "Пароль адміністратора для відновлення",
    "Enter the recovery password in order to recover the users files during password change" : "Введіть пароль для того, щоб відновити файли користувачів при зміні паролю",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Будь ласка, вкажіть розмір сховища (наприклад: \"512 MB\" або \"12 GB\")",
    "Other" : "Інше",
    "Quota" : "Квота",
    "change full name" : "змінити ім'я",
    "set new password" : "встановити новий пароль",
    "change email address" : "Змінити адресу електронної пошти",
    "Default" : "За замовчуванням"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
